import { useAutoAnimate } from '@formkit/auto-animate/react';
import Prism from 'prismjs';
import React, { useMemo, useEffect } from 'react';

const getKeyDefault = (line) => line.trimStart();
const getHighlightedLines = (props) => {
    const { value, grammar, language } = props;
    const highlightedLines = Prism.highlight(value, grammar, language)
        .split('\n')
        .map((s) => (!s ? '\n' : s));
    return highlightedLines;
};
const getLinesData = (props) => {
    const { value, getKey } = props;
    const lines = value.split('\n');
    const linesData = [];
    const usedKeys = Object.create(null);
    const ensureUnique = (key) => (usedKeys[key] ? key + ++usedKeys[key] : key);
    // It's important that we hold 2 different counters for auto-keyed ones and keyful ones.
    // `usedKeys` is a counter too.
    let j = 0;
    // let maxAnchor = 0
    lines.forEach((line) => {
        const initialKey = getKey(line);
        const key = initialKey ? ensureUnique(initialKey) : `${++j}`;
        usedKeys[key] = 1;
        const anchor = line.indexOf(initialKey);
        // if (anchor > maxAnchor) maxAnchor = anchor
        linesData.push({
            line,
            key: key,
            anchor,
        });
    });
    return linesData;
};
function CodeAnimate(props) {
    const { value, grammar = Prism.languages.jsx, language = 'javascript', animationOptions, animationEnabled, getKey = getKeyDefault, checkSpecialLine, renderSpecialLine, maxAnchor = 15, innerProps, } = props;
    const linesData = useMemo(() => getLinesData({ value, getKey }), [value, getKey]);
    const highlightedLines = useMemo(() => getHighlightedLines({ value, grammar, language }), [value]);
    const [ref, setEnabled] = useAutoAnimate({
        disrespectUserMotionPreference: true,
        ...animationOptions,
    });
    useEffect(() => setEnabled(animationEnabled), [animationEnabled]);
    return (React.createElement("code", { ref: ref, ...innerProps }, linesData.map((data, i) => checkSpecialLine?.(data.line) ? (renderSpecialLine({ line: data.line })) : (React.createElement(Line, { key: data.key, data: data, maxAnchor: maxAnchor, line: highlightedLines[i] })))));
}
const Line = (props) => {
    const { data, maxAnchor, line } = props;
    const padding = maxAnchor - data.anchor;
    return (React.createElement("pre", { dangerouslySetInnerHTML: { __html: line }, style: {
            marginLeft: -padding + 'ch',
            paddingLeft: padding + 'ch',
        } }));
};

export { CodeAnimate as default, getHighlightedLines, getLinesData };
